# xcollection

A high-level mapping of name/key to Xarray.Datasets

| CI          | [![GitHub Workflow Status][github-ci-badge]][github-ci-link] [![GitHub Workflow Status][github-lint-badge]][github-lint-link] [![Code Coverage Status][codecov-badge]][codecov-link] |
| :---------- | :----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| **Docs**    |                                                                    [![Documentation Status][rtd-badge]][rtd-link]                                                                    |
| **Package** |                                                         [![Conda][conda-badge]][conda-link] [![PyPI][pypi-badge]][pypi-link]                                                         |
| **License** |                                                                        [![License][license-badge]][repo-link]                                                                        |

[github-ci-badge]: https://img.shields.io/github/workflow/status/NCAR/xcollection/CI?label=CI&logo=github&style=for-the-badge
[github-lint-badge]: https://img.shields.io/github/workflow/status/NCAR/xcollection/linting?label=linting&logo=github&style=for-the-badge
[github-ci-link]: https://github.com/NCAR/xcollection/actions?query=workflow%3ACI
[github-lint-link]: https://github.com/NCAR/xcollection/actions?query=workflow%3Alinting
[codecov-badge]: https://img.shields.io/codecov/c/github/NCAR/xcollection.svg?logo=codecov&style=for-the-badge
[codecov-link]: https://codecov.io/gh/NCAR/xcollection
[rtd-badge]: https://img.shields.io/readthedocs/xcollection/latest.svg?style=for-the-badge
[rtd-link]: https://xcollection.readthedocs.io/en/latest/?badge=latest
[pypi-badge]: https://img.shields.io/pypi/v/xcollection?logo=pypi&style=for-the-badge
[pypi-link]: https://pypi.org/project/xcollection
[conda-badge]: https://img.shields.io/conda/vn/conda-forge/xcollection?logo=anaconda&style=for-the-badge
[conda-link]: https://anaconda.org/conda-forge/xcollection
[license-badge]: https://img.shields.io/github/license/NCAR/xcollection?style=for-the-badge
[repo-link]: https://github.com/NCAR/xcollection
